''' <summary>
''' Classe d'analyse des doublons
''' </summary>
''' <remarks></remarks>
Public NotInheritable Class ClsAnalyse
    Inherits ClsBaseThread
    ''' <summary>
    ''' Premier niveau d'analyse
    ''' </summary>
    ''' <remarks></remarks>
    Private mDict As IDict = Nothing
    ''' <summary>
    ''' Type de controle  appliquer
    ''' </summary>
    ''' <remarks></remarks>
    Private mCtrl As EFileCtrl
    ''' <summary>
    ''' Classe de listage des fichier
    ''' </summary>
    ''' <remarks></remarks>
    Private mFileList As ClsFileList = Nothing
    ''' <summary>
    ''' File d'attente des fichiers (cache)
    ''' </summary>
    ''' <remarks></remarks>
    Private mList As New Queue(Of IO.FileInfo)

    ''' <summary>
    ''' Constructeur de la classe
    ''' </summary>
    ''' <param name="pFileList">Classe de listage des fichiers</param>
    ''' <remarks></remarks>
    Public Sub New(ByVal pFileList As ClsFileList)
        MyBase.New("Analyse")

        mCtrl = CType(My.Settings.TypeCtrl, EFileCtrl)
        If (mCtrl And EFileCtrl.Extension) <> 0 Then
            mDict = New ClsDictExtension(mCtrl)
        ElseIf (mCtrl And EFileCtrl.FileName) <> 0 Then
            mDict = New ClsDictFileName(mCtrl)
        ElseIf (mCtrl And EFileCtrl.Taille) <> 0 Then
            mDict = New ClsDictSize(mCtrl)
        ElseIf (mCtrl And EFileCtrl.MD5) <> 0 Then
            mDict = New ClsDictMD5(mCtrl)
        Else
            StopThread()
            Exit Sub
        End If

        mFileList = pFileList
    End Sub

#Region "Methodes overrides"

    Protected Overrides Sub ProSubThread()
        Do While mFileList Is Nothing And mCanRun And msCanRun
            Threading.Thread.Sleep(50)
        Loop

        Do While mCanRun AndAlso mFileList IsNot Nothing AndAlso (mFileList.IsRun OrElse mFileList.NbRemainingFile > 0 OrElse mList.Count > 0)

            If mList.Count < 10 Then
                Dim lQueue As Queue(Of IO.FileInfo) = mFileList.GetFile(20 - mList.Count)

                Do While lQueue.Count > 0
                    mList.Enqueue(lQueue.Dequeue)
                Loop
            End If

            If mList.Count > 0 Then
                Dim lFile As IO.FileInfo = mList.Dequeue
                If lFile.FullName.Length < 258 Then
                    mDict.Add(lFile)
                End If
            Else
                Threading.Thread.Sleep(100)
            End If
        Loop
    End Sub

    Protected Overrides Function ProErrThread(ByVal pEx As System.Exception) As Boolean
        If TypeOf pEx Is IO.FileNotFoundException Then
            Return True
        Else
            MessageBox.Show(pEx.ToString)
            Return True
        End If
    End Function
#End Region

#Region "Membres public"
    ''' <summary>
    ''' Retourne le nombre total de doublons
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks>Retourne -1 si mDict n'est pas initialis</remarks>
    Public ReadOnly Property NbDoublons() As Integer
        Get
            If mDict Is Nothing Then
                Return -1
            Else
                Return mDict.NbDoublons
            End If
        End Get
    End Property
    ''' <summary>
    ''' Retourne les doublons sous forme de TreeNode
    ''' </summary>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Function GetNodes() As List(Of TreeNode)
        Return mDict.GetDoublons
    End Function
#End Region
End Class
